@@ -3,11 +3,8 @@ from django.db.models.query_utils import Q
 from django.conf import settings
 
 from m3 import M3JSONEncoder
-from m3.actions import (Action,
-                        PreJsonResult,
-                        OperationResult,
-                        ActionPack,
-                        ActionController,)
+from m3.actions import (
+    Action, PreJsonResult, OperationResult, ActionPack, ActionController)
 from m3.actions.tree_packs import BaseTreeDictionaryModelActions
 
 from models import KladrGeo, KladrStreet
@@ -16,15 +13,17 @@ from ui import KLADRGeoEditWindow, KLADRStreetEditWindow
 
 kladr_controller = ActionController(url='/m3-kladr')
 if hasattr(settings, 'ROOT_URL'):
-    kladr_controller.url = settings.ROOT_URL+kladr_controller.url
+    kladr_controller.url = settings.ROOT_URL + kladr_controller.url
+
 
 class Kladr_DictPack(BaseTreeDictionaryModelActions):
-    '''
-    Пак для экшенов справочника КЛАДР
-    '''
+    u"""
+    Пак для справочника КЛАДР
+    """
     url = '/kladr'
     # Включаем проверку прав пользователя.
     need_check_permission = True
+
     title = u'Классификатор адресов России (КЛАДР)'
     verbose_name = u'Классификатор адресов России (КЛАДР)'
     tree_model = KladrGeo
@@ -42,84 +41,116 @@ class Kladr_DictPack(BaseTreeDictionaryModelActions):
     width, height = 910, 600
     tree_width = 390
 
-    edit_window = KLADRGeoEditWindow
-    edit_node_window = KLADRStreetEditWindow
+    edit_window = KLADRStreetEditWindow
+    edit_node_window = KLADRGeoEditWindow
+
 
 class KLADRPack(ActionPack):
+    u"""
+    Пак действий с КЛАДРом
+    """
     url = ''
+
     def __init__(self):
         super(KLADRPack, self).__init__()
         self.get_places_action = KLADRRowsAction()
         self.get_streets_action = StreetRowsAction()
         self.get_addr_action = KLADRGetAddrAction()
-        self.actions = [self.get_places_action, self.get_streets_action, self.get_addr_action]
+        self.actions = [
+            self.get_places_action,
+            self.get_streets_action,
+            self.get_addr_action
+        ]
 
     @classmethod
-    def get_place_name(self, code):
-        place = KladrGeo.objects.select_related('parent').\
-                select_related('parent__parent').\
-                select_related('parent__parent__parent').\
-                filter(code = code)
+    def get_place_name(cls, code):
+        u"""
+        Возвращает имя географического объекта (субъекта, населенного пункта)
+        в строковом виде по коду
+        """
+        place = KladrGeo.objects.select_related(
+            'parent', 'parent__parent', 'parent__parent__parent'
+        ).filter(
+            code=code
+        )
         return place[0].display_name() if place else ''
 
     @classmethod
-    def get_place(self, code):
-        place = KladrGeo.objects.select_related('parent').\
-                select_related('parent__parent').\
-                select_related('parent__parent__parent').\
-                filter(code = code)
+    def get_place(cls, code):
+        u"""
+        Возвращает геграфический объект в JSON-формате по коду
+        """
+        place = KladrGeo.objects.select_related(
+            'parent', 'parent__parent', 'parent__parent__parent'
+        ).filter(
+            code=code
+        )
         return M3JSONEncoder().encode(place[0]) if place else None
 
     @classmethod
-    def get_street_name(self, code):
-        street = KladrStreet.objects.select_related('parent').filter(code = code)
+    def get_street_name(cls, code):
+        u"""
+        Возвращает полный адрес в строковом виде по коду
+        """
+        street = KladrStreet.objects.select_related('parent').filter(code=code)
         return street[0].display_name() if street else ''
 
     @classmethod
-    def get_street(self, code):
-        street = KladrStreet.objects.select_related('parent').filter(code = code)
+    def get_street(cls, code):
+        u"""
+        Возвращает объект улицы в JSON-формате по коду
+        """
+        street = KladrStreet.objects.select_related('parent').filter(code=code)
         return M3JSONEncoder().encode(street[0]) if street else None
 
+
 class KLADRRowsAction(Action):
-    '''
-    Перечисление элементов КЛАДРа
-    '''
+    u"""
+    Экшен, возвращающий строки с географическими объектами
+    """
     url = '/kladr_rows$'
+    MAX_DEPTH = 3  # макс. глубина вложенности детей в родителя
 
     def run(self, request, context):
         filter = request.REQUEST.get('filter')
-        if filter: # бывают случаи, когда фильтр приходит пустой
-            fields = ['name','code','socr'];
+        if filter:  # бывают случаи, когда фильтр приходит пустой
+            fields = ['name', 'code', 'socr']
             words = filter.strip().split(' ')
             # первым этапом найдем территории подходящие под фильтр в имени
-            condition = None
+            condition = Q()
             for word in words:
-                field_condition = None
+                field_condition = Q()
                 for field_name in fields:
-                    field = Q(**{field_name + '__icontains': word})
-                    field_condition = field_condition | field if field_condition else field
-                condition = condition & field_condition if condition else field_condition
-            places = KladrGeo.objects.filter(condition).select_related('parent').\
-                     select_related('parent__parent').\
-                     select_related('parent__parent__parent').\
-                     order_by('level','name')[0:50]
+                    field_condition |= Q(**{field_name + '__icontains': word})
+
+                condition &= field_condition
+
+            places = KladrGeo.objects.filter(condition).select_related(
+                'parent', 'parent__parent', 'parent__parent__parent'
+            ).order_by(
+                'level', 'name'
+            )[0:50]
             # если не нашли, то будем искать с учетом родителей
             if len(places) == 0:
-                condition = None
+                condition = Q()
                 for word in words:
-                    field_condition = None
+                    field_condition = Q()
                     for field_name in fields:
-                        field = Q(**{field_name + '__icontains': word}) |\
-                                Q(**{'parent__' + field_name + '__icontains': word}) |\
-                                Q(**{'parent__parent__' + field_name + '__icontains': word}) |\
-                                Q(**{'parent__parent__parent__' + field_name + '__icontains': word})
-                        field_condition = field_condition | field if field_condition else field
-                    condition = condition & field_condition if condition else field_condition
-                places = KladrGeo.objects.filter(condition).\
-                         select_related('parent').\
-                         select_related('parent__parent').\
-                         select_related('parent__parent__parent').\
-                         order_by('level','name')[0:50]
+                        for depth in range(self.MAX_DEPTH + 1):
+                            field_condition |= Q(**{
+                                '{}{}__icontains'.format(
+                                    'parent__' * depth,
+                                    field_name
+                                ): word
+                            })
+
+                    condition &= field_condition
+
+                places = KladrGeo.objects.filter(condition).select_related(
+                    'parent', 'parent__parent', 'parent__parent__parent'
+                ).order_by(
+                    'level', 'name'
+                )[0:50]
         else:
             places = []
         result = {'rows': list(places), 'total': len(places)}
@@ -127,8 +158,8 @@ class KLADRRowsAction(Action):
 
 
 class StreetRowsAction(Action):
-    """
-    Перечисление улиц
+    u"""
+    Экшен, возвращающий строки с улицами
     """
     url = '/street_rows$'
 
@@ -184,7 +215,7 @@ class StreetRowsAction(Action):
                     for field_name in fields:
                         for depth in range(self.MAX_DEPTH + 1):
                             field_condition |= Q(**{
-                                '%s%s__icontains' % (
+                                '%s%s__icontains'.format(
                                     'parent__' * depth,
                                     field_name
                                 ): word
@@ -196,11 +227,20 @@ class StreetRowsAction(Action):
         result = {'rows': list(places), 'total': len(places)}
         return PreJsonResult(result)
 
-def GetAddr(place, street = None, house = None, flat = None, zipcode = None, corps = None):
-    """
+
+def GetAddr(place, street=None, house=None, flat=None, zipcode=None, corps=None):
+    u"""
     Формирует строку полного адреса по выбранным значениям КЛАДРа
+
+    :param place: населенный пункт
+    :param street: улица
+    :param house: дом
+    :param flat: квартира
+    :param zipcode: индекс
+    :param corps: корпус
+    :return:
     """
-    if not place: # бывают случаи, когда территория приходит пустой
+    if not place:  # бывают случаи, когда территория приходит пустой
         return ''
     # Получаем населенный пункт
     if isinstance(place, (str, unicode)):
@@ -219,10 +259,10 @@ def GetAddr(place, street = None, house = None, flat = None, zipcode = None, cor
             street = qs.get()
         else:
             street = None
-    elif (street!=None) and (not isinstance(street, KladrStreet)):
+    elif street and not isinstance(street, KladrStreet):
         raise TypeError()
 
-    '''
+    u"""
     типАдреса = 0 или 1
     текИндекс = 0
     адрес = ""
@@ -266,7 +306,7 @@ def GetAddr(place, street = None, house = None, flat = None, zipcode = None, cor
             адрес = раделитель+индекс+раделитель+адрес
         иначе
             адрес = раделитель+раделитель+адрес
-    '''
+    """
     addr_type = 0
     curr_index = zipcode or ''
     addr_text = ''
@@ -280,12 +320,13 @@ def GetAddr(place, street = None, house = None, flat = None, zipcode = None, cor
     else:
         delim = ','
     while curr_item:
-        if addr_type != 0 and curr_item.parent == None:
+        if addr_type != 0 and not curr_item.parent:
             break
         if curr_index == '' and curr_item.zipcode:
             curr_index = curr_item.zipcode
         if addr_type == 0:
-            addr_text = curr_item.socr+" "+curr_item.name+delim+addr_text
+            addr_text = ''.join((
+                curr_item.socr, " ", curr_item.name, delim, addr_text))
         else:
             if curr_item == street:
                 lv = 4
@@ -293,39 +334,41 @@ def GetAddr(place, street = None, house = None, flat = None, zipcode = None, cor
                 lv = curr_item.level
             while curr_level > lv:
                 curr_level -= 1
-                addr_text = delim+addr_text
-            addr_text = curr_item.socr+" "+curr_item.namebind_pack+delim+addr_text
+                addr_text = ''.join((delim, addr_text))
+            addr_text = ''.join((
+                curr_item.socr, " ", curr_item.namebind_pack, delim, addr_text
+            ))
             curr_level -= 1
         curr_item = curr_item.parent
     if addr_type == 0:
         if curr_index != '':
-            addr_text = curr_index+delim+addr_text
+            addr_text = ''.join((curr_index, delim, addr_text))
     else:
         while curr_level > 1:
             curr_level -= 1
-            addr_text = delim+addr_text
-        addr_text = u'регион'+delim+addr_text
+            addr_text = delim + addr_text
+        addr_text = ''.join((u'регион', delim, addr_text))
         if curr_index != '':
-            addr_text = curr_index+delim+addr_text
+            addr_text = ''.join((curr_index, delim, addr_text))
         else:
-            addr_text = delim+delim+addr_text
+            addr_text = ''.join((delim, delim, addr_text))
     # если нет дома и корпуса и квартиры, то уберем последний разделитель
     if not (house or corps or flat):
         addr_text = addr_text.rstrip(delim)
     else:
         if house:
-            addr_text = addr_text+u'д. '+house
+            addr_text = ''.join((addr_text, u'д. ', house))
         if corps:
-            addr_text = u'%s%sкорп. %s'%(addr_text, delim, corps)
+            addr_text = u'{}{}корп. {}'.format(addr_text, delim, corps)
         if flat:
-            addr_text = addr_text+delim+u'кв. '+flat
+            addr_text = ''.join((addr_text, delim, u'кв. ', flat))
     return addr_text
 
 
 class KLADRGetAddrAction(Action):
-    '''
+    u"""
     Расчет адреса по составляющим
-    '''
+    """
     url = '/kladr_getaddr$'
 
     def run(self, request, context):
@@ -336,5 +379,8 @@ class KLADRGetAddrAction(Action):
         zipcode = request.REQUEST.get('zipcode')
         addr_cmp = request.REQUEST.get('addr_cmp', '')
         addr_text = GetAddr(place, street, house, flat, zipcode)
-        result = u'(function(){ Ext.getCmp("%s").setValue("%s");})()' % (addr_cmp, addr_text or '')
-        return OperationResult(success=True, code = result)
+        result = u'''(function () {{
+            Ext.getCmp("{0}").setValue("{1}");
+        }})()
+        '''.format(addr_cmp, addr_text or '')
+        return OperationResult(success=True, code=result)
