@@ -7,17 +7,18 @@ from m3 import authenticated_user_required
 
 
 def register_actions():
-    kladr_controller.packs.append(KLADRPack)
+    kladr_controller.packs.append(KLADRPack())
     #kladr_controller.rebuild_patterns()
 
 
 def register_urlpatterns():
-    '''
+    u"""
     Регистрация конфигурации урлов для приложения kladr
-    '''
-    return urls.defaults.patterns('',
-                                  (r'^m3-kladr', 'kladr.app_meta.kladr_view'),
-                                  )
+    """
+    return urls.defaults.patterns(
+        '', (r'^m3-kladr', 'kladr.app_meta.kladr_view'),
+    )
+
 
 #===============================================================================
 # Представления
